# Model Schema

These are the validated training-side schema objects used to define model architectures, heads, and layer
configuration in YAML.

::: fast_plate_ocr.train.model.model_schema
    options:
      show_if_no_docstring: true
      filters:
        - "!^__"
